@@ -21,7 +21,7 @@
 (*                                                                        *)
 (**************************************************************************)
 
-(* $Id: searchid.ml 1352 2007-07-12 08:56:18Z zoggy $ *)
+(* $Id: searchid.ml 1510 2010-05-20 10:01:57Z garrigue $ *)
 
 open StdLabels
 open Location
@@ -94,7 +94,7 @@ let rec choose n ~card:l =
   if n = 1 then List.map l ~f:(fun x -> [x]) else
   if n = 0 then [[]] else
   if n > len then [] else
-  match l with [] -> [] 
+  match l with [] -> []
   | a :: l ->
     List.map (choose (n-1) ~card:l) ~f:(fun l -> a :: l)
     @ choose n ~card:l
@@ -107,7 +107,7 @@ let rec all_args ty =
   match ty.desc with
     Tarrow(l, ty1, ty2, _) -> let (tl,ty) = all_args ty2 in ((l,ty1)::tl, ty)
   | _ -> ([], ty)
-  
+
 let rec equal ~prefix t1 t2 =
   match (repr t1).desc, (repr t2).desc with
     Tvar, Tvar -> true
@@ -157,7 +157,7 @@ let rec included ~prefix t1 t2 =
   | Tvariant row1, Tvariant row2 ->
       let row1 = row_repr row1 and row2 = row_repr row2 in
       let fields1 = filter_row_fields false row1.row_fields
-      and fields2 = filter_row_fields false row1.row_fields
+      and fields2 = filter_row_fields false row2.row_fields
       in
       let r1, r2, pairs = merge_row_fields fields1 fields2 in
       r1 = [] &&
@@ -237,9 +237,9 @@ let rec search_type_in_signature t ~sign ~prefix ~mode =
           end ||
           begin match td.type_kind with
             Type_abstract -> false
-          | Type_variant (l, priv) ->
+          | Type_variant l ->
             List.exists l ~f:(fun (_, l) -> List.exists l ~f:matches)
-          | Type_record(l, rep, priv) ->
+          | Type_record(l, rep) ->
             List.exists l ~f:(fun (_, _, t) -> matches t)
           end
           then [lid_of_id id, Ptype] else []
@@ -322,7 +322,7 @@ let search_string_type text ~mode =
       let start_c = l.loc_start.Lexing.pos_cnum in
       let end_c = l.loc_end.Lexing.pos_cnum in
       raise (Error (start_c - 8, end_c - 8))
-      
+
 let longident_of_string text =
   let exploded = ref [] and l = ref 0 in
   for i = 0 to String.length text - 2 do
@@ -423,13 +423,14 @@ let rec bound_variables pat =
   | Ppat_construct (_,Some pat,_) -> bound_variables pat
   | Ppat_variant (_,None) -> []
   | Ppat_variant (_,Some pat) -> bound_variables pat
-  | Ppat_record l ->
+  | Ppat_record (l, _) ->
       List2.flat_map l ~f:(fun (_,pat) -> bound_variables pat)
   | Ppat_array l ->
       List2.flat_map l ~f:bound_variables
   | Ppat_or (pat1,pat2) ->
       bound_variables pat1 @ bound_variables pat2
   | Ppat_constraint (pat,_) -> bound_variables pat
+  | Ppat_lazy pat -> bound_variables pat
 
 let search_structure str ~name ~kind ~prefix =
   let loc = ref 0 in
