@@ -21,7 +21,7 @@
 (*                                                                        *)
 (**************************************************************************)
 
-(* $Id: searchpos.ml 1377 2007-09-25 15:30:14Z garrigue $ *)
+(* $Id: searchpos.ml 1510 2010-05-20 10:01:57Z garrigue $ *)
 
 open StdLabels
 open Parsetree
@@ -136,6 +136,8 @@ let rec search_pos_type t ~pos ~env =
       add_found_sig (`Type, lid) ~env ~loc:t.ptyp_loc
   | Ptyp_alias (t, _)
   | Ptyp_poly (_, t) -> search_pos_type ~pos ~env t
+  | Ptyp_package (_, stl) ->
+     List.iter stl ~f:(fun (_, ty) -> search_pos_type ty ~pos ~env)
   end
 
 let rec search_pos_class_type cl ~pos ~env =
@@ -171,11 +173,11 @@ let search_pos_type_decl td ~pos ~env =
     | None -> ()
     end;
     begin match td.ptype_kind with
-      Ptype_abstract | Ptype_private -> ()
-    | Ptype_variant (dl, priv) ->
+      Ptype_abstract -> ()
+    | Ptype_variant dl ->
         List.iter dl
           ~f:(fun (_, tl, _) -> List.iter tl ~f:(search_pos_type ~pos ~env))
-    | Ptype_record (dl, priv) ->
+    | Ptype_record dl ->
         List.iter dl ~f:(fun (_, _, t, _) -> search_pos_type t ~pos ~env)
     end;
     List.iter td.ptype_cstrs ~f:
@@ -184,7 +186,7 @@ let search_pos_type_decl td ~pos ~env =
         search_pos_type t2 ~pos ~env
       end
   end
-  
+
 let rec search_pos_signature l ~pos ~env =
   ignore (
   List.fold_left l ~init:env ~f:
@@ -209,7 +211,7 @@ let rec search_pos_signature l ~pos ~env =
       | Psig_exception (_, l) ->
           List.iter l ~f:(search_pos_type ~pos ~env);
           add_found_sig (`Type, Lident "exn") ~env ~loc:pt.psig_loc
-      | Psig_module (_, t) -> 
+      | Psig_module (_, t) ->
           search_pos_module t ~pos ~env
       | Psig_recmodule decls ->
           List.iter decls ~f:(fun (_, t) -> search_pos_module t ~pos ~env)
@@ -222,7 +224,7 @@ let rec search_pos_signature l ~pos ~env =
       | Psig_class_type l ->
           List.iter l
             ~f:(fun ci -> search_pos_class_type ci.pci_expr ~pos ~env)
-      (* The last cases should not happen in generated interfaces *) 
+      (* The last cases should not happen in generated interfaces *)
       | Psig_open lid -> add_found_sig (`Module, lid) ~env ~loc:pt.psig_loc
       | Psig_include t -> search_pos_module t ~pos ~env
       end;
@@ -241,9 +243,11 @@ and search_pos_module m ~pos ~env =
         search_pos_module m ~pos ~env;
         List.iter l ~f:
           begin function
-              _, Pwith_type t -> search_pos_type_decl t ~pos ~env 
+              _, Pwith_type t -> search_pos_type_decl t ~pos ~env
             | _ -> ()
           end
+    | Pmty_typeof md -> 
+        ()   (* TODO? *)
     end
   end
 
@@ -389,11 +393,12 @@ let rec view_signature ?title ?path ?(env = !start_env) ?(detach=false) sign =
   let text = tb#get_text () in
   let tpos = Lexical.tpos ~start:tb#start_iter in
   let pt =
-    try Parse.interface (Lexing.from_string text) with
-      Syntaxerr.Error e ->
+      try Parse.interface (Lexing.from_string text)
+      with Syntaxerr.Error e ->
         let l =
           match e with
             Syntaxerr.Unclosed(l,_,_,_) -> l
+          | Syntaxerr.Applicative_path l -> l
           | Syntaxerr.Other l -> l
         in
         tb#apply_tag_by_name "error"
@@ -447,7 +452,7 @@ and view_signature_item sign ~path ~env =
 
 and view_module path ~env =
   match find_module path env with
-    Tmty_signature sign -> 
+    Tmty_signature sign ->
       !view_defined_ref (Searchid.longident_of_path path) ~env
   | modtype ->
       let id = ident_of_path path ~default:"M" in
@@ -810,6 +815,8 @@ and search_pos_expr ~pos exp =
       search_pos_expr exp ~pos
   | Texp_object (cls, _, _) ->
       search_pos_class_structure ~pos cls
+  | Texp_pack modexp ->
+      search_pos_module_expr modexp ~pos
   end;
   add_found_str (`Exp(`Expr, exp.exp_type)) ~env:exp.exp_env ~loc:exp.exp_loc
   end
@@ -822,6 +829,7 @@ and search_pos_pat ~pos ~env pat =
       add_found_str (`Exp(`Val (Pident id), pat.pat_type))
         ~env ~loc:pat.pat_loc
   | Tpat_alias (pat, _) -> search_pos_pat pat ~pos ~env
+  | Tpat_lazy pat -> search_pos_pat pat ~pos ~env
   | Tpat_constant _ ->
       add_found_str (`Exp(`Const, pat.pat_type)) ~env ~loc:pat.pat_loc
   | Tpat_tuple l ->
@@ -853,6 +861,7 @@ and search_pos_module_expr ~pos m =
     | Tmod_apply (a, b, _) ->
         search_pos_module_expr a ~pos; search_pos_module_expr b ~pos
     | Tmod_constraint (m, _, _) -> search_pos_module_expr m ~pos
+    | Tmod_unpack (e, _) -> search_pos_expr e ~pos
     end;
     add_found_str (`Module (Pident (Ident.create "M"), m.mod_type))
       ~env:m.mod_env ~loc:m.mod_loc
