@@ -20,7 +20,7 @@
 /*                                                                        */
 /**************************************************************************/
 
-/* $Id$ */
+/* $Id: ml_gpointer.c 1347 2007-06-20 07:40:34Z guesdon $ */
 
 #include <caml/mlvalues.h>
 #include <caml/alloc.h>
@@ -33,7 +33,7 @@
 
 CAMLprim value ml_stable_copy (value v)
 {
-    if (Is_young_block(v))
+    if (Is_block(v) && (char*)(v) < young_end && (char*)(v) > young_start)
     {
         CAMLparam1(v);
         mlsize_t i, wosize = Wosize_val(v);
